![](img/Unifile_logo.png)

# Unifile

This file content examples how to use this module
is for saving and loading many file formats 

> `pip install unifile`

## Supported formats

-   [x] yaml
-   [x] txt
-   [x] csv
-   [x] json (load content from url or local file)
-   [x] pdf (only can load text)

For doc see [how_to_use_example.py](how_to_use_example.py) in my github repository.
And also in unifile module you can look well documented functions

!!! All dump function replace file can't add data to existing file 

## Contribute

If you have idea what add or change make better or help you can.
